Error

Enum Error 

pub enum Error {
Show 62 variants Other(PyErr), UnknownFormat(String), NotBranchError(String, Option<String>), NoColocatedBranchSupport, DependencyNotPresent(String, String), PermissionDenied(PathBuf, Option<String>), UnsupportedProtocol(String, Option<String>), UnusableRedirect(String, String, String), ConnectionError(String), InvalidURL(String, Option<String>), TransportError(String), UnsupportedFormat(String), UnsupportedVcs(String), RemoteGitError(String), IncompleteRead(Vec<u8>, Option<usize>), LineEndingError(String), InvalidHttpResponse(String, String, Option<String>, HashMap<String, String>), AlreadyControlDir(PathBuf), AlreadyBranch(PathBuf), DivergedBranches, WorkspaceDirty(PathBuf), NoSuchFile(PathBuf), PointlessCommit, NoWhoami, NoSuchTag(String), TagAlreadyExists(String), Socket(Error), ForgeLoginRequired, UnsupportedForge(Url), ForgeProjectExists(String), MergeProposalExists(Url, Option<Url>), UnsupportedOperation(String, String), ProtectedBranchHookDeclined(String), NoRepositoryPresent, LockFailed(String), FileExists(PathBuf, Option<String>), LockContention(String, String), NotImplemented, NoSuchRevisionInTree(RevisionId), MissingNestedTree(PathBuf), ImmortalLimbo(PathBuf), MalformedTransform(Vec<RawConflict>), TransformRenameFailed(PathBuf, PathBuf, String, Error), UnexpectedHttpStatus { url: Url, code: u16, extra: Option<String>, headers: HashMap<String, String>, }, Timeout, BadHttpRequest(Url, String), TransportNotPossible(String), IncompatibleFormat(String, String), NoSuchRevision(RevisionId), RevisionNotPresent(RevisionId), NoSuchProject(String), ForkingDisabled(String), ProjectCreationTimeout(String, Duration), GitLabConflict(String), SourceNotDerivedFromTarget, BranchReferenceLoop, RedirectRequested { source: Url, target: Url, is_permanent: bool, }, ConflictsInTree, NoRoundtrippingSupport, NoCompatibleInter, ReadOnly, ObjectNotLocked(String),
}
Error type for the Breezy Rust wrapper.

This enum represents the various errors that can occur when using the Breezy API through this Rust wrapper. Each variant corresponds to a specific error condition, with many mapping directly to Python exceptions from the Breezy library.

Variants



Other(PyErr)

A Python error that doesn’t map to a specific variant.



UnknownFormat(String)

An unknown format was encountered.



NotBranchError(String, Option<String>)

The specified path is not a branch.



NoColocatedBranchSupport

The repository format doesn’t support colocated branches.



DependencyNotPresent(String, String)

A required dependency is not present.



PermissionDenied(PathBuf, Option<String>)

Permission was denied when accessing a path.



UnsupportedProtocol(String, Option<String>)

The specified protocol is not supported.



UnusableRedirect(String, String, String)

A redirect could not be followed.



ConnectionError(String)

A connection error occurred.



InvalidURL(String, Option<String>)

The specified URL is invalid.



TransportError(String)

An error occurred during transport.



UnsupportedFormat(String)

The specified format is not supported.



UnsupportedVcs(String)

The specified version control system is not supported.



RemoteGitError(String)

An error occurred when interacting with a remote Git repository.



IncompleteRead(Vec<u8>, Option<usize>)

A read operation did not complete (partial read).



LineEndingError(String)

An error occurred with line endings in a file.



InvalidHttpResponse(String, String, Option<String>, HashMap<String, String>)

An invalid HTTP response was received.



AlreadyControlDir(PathBuf)

A control directory already exists at the specified path.



AlreadyBranch(PathBuf)

A branch already exists at the specified path.



DivergedBranches

The branches have diverged.



WorkspaceDirty(PathBuf)

The workspace has uncommitted changes.



NoSuchFile(PathBuf)

The specified file does not exist.



PointlessCommit

The commit would not change anything.



NoWhoami

No user identity has been configured.



NoSuchTag(String)

The specified tag does not exist.



TagAlreadyExists(String)

The specified tag already exists.



Socket(Error)

A socket error occurred.



ForgeLoginRequired

Login to the forge is required.



UnsupportedForge(Url)

The specified forge is not supported.



ForgeProjectExists(String)

A project already exists on the forge.



MergeProposalExists(Url, Option<Url>)

A merge proposal already exists.



UnsupportedOperation(String, String)

The operation is not supported.



ProtectedBranchHookDeclined(String)

A protected branch hook declined the push.



NoRepositoryPresent

No repository is present at the specified location.



LockFailed(String)

Failed to acquire a lock.



FileExists(PathBuf, Option<String>)

A file already exists at the specified path.



LockContention(String, String)

Lock contention occurred.



NotImplemented

The requested operation is not implemented.



NoSuchRevisionInTree(RevisionId)

The specified revision is not in the tree.



MissingNestedTree(PathBuf)

A nested tree is missing at the specified path.



ImmortalLimbo(PathBuf)

Failed to delete transform temporary directory.



MalformedTransform(Vec<RawConflict>)

The transform is malformed.



TransformRenameFailed(PathBuf, PathBuf, String, Error)

Failed to rename a file during a transform operation.



UnexpectedHttpStatus

An unexpected HTTP status code was received.

Fields

url: Url

The URL that was requested.

code: u16

The HTTP status code that was received.

extra: Option<String>

Additional information about the error.

headers: HashMap<String, String>

The HTTP headers that were received.



Timeout

A timeout occurred.



BadHttpRequest(Url, String)

A bad HTTP request was made.



TransportNotPossible(String)

The transport is not possible.



IncompatibleFormat(String, String)

The format is not compatible.



NoSuchRevision(RevisionId)

The specified revision does not exist.



RevisionNotPresent(RevisionId)

The specified revision is not present in the repository.



NoSuchProject(String)

The specified project does not exist.



ForkingDisabled(String)

Forking is disabled for the specified project.



ProjectCreationTimeout(String, Duration)

The project creation timed out.



GitLabConflict(String)

A conflict occurred in GitLab.



SourceNotDerivedFromTarget

The source branch is not derived from the target branch.



BranchReferenceLoop

A loop was detected in branch references.



RedirectRequested

A redirect was requested.

Fields

source: Url

The source URL.

target: Url

The target URL.

is_permanent: bool

Whether the redirect is permanent.



ConflictsInTree

There are conflicts in the tree.



NoRoundtrippingSupport

The operation does not support roundtripping.



NoCompatibleInter

No compatible inter-repository implementation was found.



ReadOnly

The resource is read-only.



ObjectNotLocked(String)

An object that needs to be locked is not locked.