PyWorkingTree

Trait PyWorkingTree 

pub trait PyWorkingTree: PyMutableTree + WorkingTree { }
Trait for working trees that wrap Python working tree objects.

This trait is implemented by working tree types that wrap Python working tree objects.

Implementations

Source

impl dyn PyWorkingTree

pub fn as_working_tree(&self) -> &dyn WorkingTree

Get a reference to self as a WorkingTree trait object.

Implementors