pub struct GenericWorkingTree(pub Py<PyAny>);Expand description
A working tree in a version control system.
A working tree is a local directory containing the files of a branch that can be edited. This struct wraps a Python working tree object and provides access to its functionality.
Tuple Fields
0: Py<PyAny>Implementations
Sourceimpl GenericWorkingTree
impl GenericWorkingTree
Sourcepub fn open_containing(
path: &Path,
) -> Result<(GenericWorkingTree, PathBuf), Error>
👎Deprecated: Use ::open_containing instead
pub fn open_containing( path: &Path, ) -> Result<(GenericWorkingTree, PathBuf), Error>
Use ::open_containing instead
Open a working tree containing the specified path.
This method is deprecated, use the module-level open_containing function instead.
Parameters
path- The path to look for a containing working tree.
Returns
A tuple containing the working tree and the relative path, or an error if no containing working tree could be found.
Sourcepub fn commit(
&self,
message: &str,
committer: Option<&str>,
timestamp: Option<f64>,
allow_pointless: Option<bool>,
specific_files: Option<&[&Path]>,
) -> Result<RevisionId, Error>
👎Deprecated: Use build_commit instead
pub fn commit( &self, message: &str, committer: Option<&str>, timestamp: Option<f64>, allow_pointless: Option<bool>, specific_files: Option<&[&Path]>, ) -> Result<RevisionId, Error>
Use build_commit instead
Create a commit with the specified parameters.
This method is deprecated, use the build_commit method instead.
Parameters
message- The commit message.allow_pointless- Whether to allow commits that don’t change any files.committer- The committer’s name and email.specific_files- The paths of files to include in this commit.
Returns
The revision ID of the new commit, or an error if the commit could not be created.