pub trait PyWorkingTree: PyMutableTree + WorkingTree { }Expand description
Trait for working trees that wrap Python working tree objects.
This trait is implemented by working tree types that wrap Python working tree objects.
Implementations
Sourceimpl dyn PyWorkingTree
impl dyn PyWorkingTree
Sourcepub fn as_working_tree(&self) -> &dyn WorkingTree
pub fn as_working_tree(&self) -> &dyn WorkingTree
Get a reference to self as a WorkingTree trait object.